# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu System Tests
# Copyright (C) 2016-2017 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
import os
from ubuntu_system_tests.helpers import file_system as fs
from ubuntu_system_tests.helpers.calculator.app import APP_ID
from ubuntu_system_tests.helpers.configuration import Config
from ubuntu_system_tests.helpers.snap import (
    get_snap_revision,
)
from ubuntu_system_tests.helpers.unity8.utils import is_unity8_snap

CALCULATOR_CONF_FILE = "com.ubuntu.calculator.conf"


class CalculatorConfig(Config):

    def __init__(self):
        if is_unity8_snap():
            rev = get_snap_revision(APP_ID)
            conf_dir = fs.get_home_snap_path(
                APP_ID, rev, fs.DIR_CONFIG, fs.DIR_CALCULATOR)
        else:
            conf_dir = os.path.join(fs.DIR_HOME_CONFIG, fs.DIR_CALCULATOR)
        self.conf_file_path = os.path.join(conf_dir, CALCULATOR_CONF_FILE)
        if not os.path.exists(conf_dir):
            os.makedirs(conf_dir)
        if not os.path.exists(self.conf_file_path):
            open(self.conf_file_path, 'w+')
        super().__init__()

    def config_walkthrough(self, first_run="false"):
        self.set_config_value("General", "firstRun", first_run)
