# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

# Ubuntu System Tests
# Copyright (C) 2015, 2016 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import os

from ubuntu_system_tests.helpers import processes
from ubuntu_system_tests.helpers.application import Application
from ubuntu_system_tests.helpers import file_system as fs

APP = 'music-app'
APP_NAME = 'Music'
APP_ID = 'com.ubuntu.music'
APP_WIN_ID = 'com.ubuntu.music_music'
QML = 'music-app.qml'

CONFIG_FILE = os.path.join(fs.DIR_HOME_MUSIC_CONFIG, '{}.conf'.format(APP_ID))


class MusicPlayer(Application):

    def __init__(self):
        super().__init__(APP_NAME, APP_ID)

    def is_running(self):
        """ Indicate if the music app is currently running """
        return processes.is_qmlscene_running_with_qmlfile(APP)

    def get_main_view(self):
        """
        Return music app proxy object from existing process.
        :return: Proxy object for music application.
        """
        from ubuntu_system_tests.helpers.music import cpo  # NOQA
        proxy = self.get_proxy_object()
        return proxy.main_view

    @staticmethod
    def stop():
        """ Stop the music app qml process """
        processes.stop_qmlscene_process(QML)
