# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu System Tests
# Copyright (C) 2015 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import logging
import threading

from gi.repository import Accounts, GLib
from autopilot.exceptions import StateNotFoundError

from ubuntu_system_tests.helpers.input_manager import input_manager
from ubuntu_system_tests.helpers.scopes.base import (
    Preview as PreviewBase
)

logger = logging.getLogger(__name__)


class Preview(PreviewBase):

    @classmethod
    def validate_dbus_object(cls, path, state):
        """This class can never be selected."""
        return False

    def get_details(self):
        """Return the details of the application whose preview is open."""
        header_widget = self.select_single('PreviewWidget', objectName='hdr')
        title_label = header_widget.select_single(
            'Label', objectName='titleLabel')
        subtitle_label = header_widget.select_single(
            'Label', objectName='subtitleLabel')
        return dict(
            title=title_label.text, subtitle=subtitle_label.text)

    def install(self):
        install_button = self.select_single(
            'PreviewActionButton', objectName='buttoninstall_click')
        input_manager.pointer.click_object(install_button)

    def is_progress_bar_visible(self):
        try:
            self.select_single('ProgressBar', objectName='progressBar')
            return True
        except StateNotFoundError:
            return False


class AccountManager(object):

    def __init__(self):
        self.manager = Accounts.Manager()

    def _start_main_loop(self):
        self.error = None
        self._main_loop = GLib.MainLoop()
        self._main_loop_thread = threading.Thread(
            target=self._main_loop.run)
        self._main_loop_thread.start()

    def delete_account(self, account):
        self._start_main_loop()
        account.delete()
        account.store(self._on_account_deleted, None)
        self._join_main_loop()

    def _join_main_loop(self):
        self._main_loop_thread.join()
        if self.error is not None:
            raise Exception(self.error.message)

    def _on_account_deleted(self, account, error, userdata):
        if error:
            self.error = error
        self._main_loop.quit()
