# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
#
# Ubuntu System Tests
# Copyright (C) 2017 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import json
import requests_unixsocket

from urllib.parse import quote_plus

SOCK_SNAPD = '/run/snapd.socket'


def get_snap_data(snap_name):
    """Return snap data dictionary or None if not found."""
    session = requests_unixsocket.Session()
    path = quote_plus(SOCK_SNAPD)
    url = 'http+unix://{p}/v2/snaps/{s}'.format(p=path, s=snap_name)
    response = session.get(url)
    if not response.ok:
        return None
    return json.loads(response.content.decode())['result']


def get_snap_revision(snap_name):
    """Return the revision of the specified snap.
    :param snap_name: Name of the required snap package.
    :return: Revision number as string.
    """
    snap_data = get_snap_data(snap_name)
    if snap_data is None:
        raise RuntimeError(
            'Snap {s} not found'.format(s=snap_name))
    return snap_data['revision']


def is_installed(snap_name):
    """Return boolean indicating if snap is installed or not."""
    return bool(get_snap_data(snap_name))
