# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu System Tests
# Copyright (C) 2014-2017 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
from ubuntu_system_tests.helpers import autopilot
from ubuntu_system_tests.helpers import processes
from ubuntu_system_tests.helpers.application import (
    Deb,
    Snap,
)
from ubuntu_system_tests.helpers.processes import get_process_id
from ubuntu_system_tests.helpers.scopes.apps import (
    launch_application_from_apps_scope
)

APP = 'system-settings'
APP_NAME = 'System Settings'
APP_WIN_ID = 'ubuntu-system-settings'
APP_ID = 'ubuntu-system-settings'


class SystemSettingsDeb(Deb):

    def __init__(self):
        super().__init__(APP_NAME, APP_ID)

    def get_main_view(self):
        return get_main_view()


class SystemSettingsSnap(Snap):

    def __init__(self):
        super().__init__(APP_NAME, APP_ID)

    def get_main_view(self):
        return get_main_view()


def get_main_view():
    from ubuntu_system_tests.helpers.system_settings import cpo  # NOQA
    pid = get_process_id(APP)
    return autopilot.get_proxy_object(pid=pid).main_view


def get_system_settings_app(mode):
    """Return system settings application class of required type.
    :param mode: Either 'snap' or 'deb'.
    :return: Either SystemSettingsDeb or SystemSettingsSnap class reference.
    """
    app_modes = {
        'deb': SystemSettingsDeb,
        'snap': SystemSettingsSnap
    }
    return app_modes[mode]


def launch_system_settings(shell):
    """
    Launch system settings from apps scope and return proxy object.

    :return: Proxy object for system settings.

    """
    launch_application_from_apps_scope(APP_NAME)
    return get_system_settings_proxy()


def is_system_settings_running():
    """ Indicate if the system settings is currently running """
    return processes.is_process_running(APP)


def get_system_settings_proxy():
    """
    Return system settings proxy object from existing process.

    :return: Proxy object for system settings.

    """
    from ubuntu_system_tests.helpers.system_settings import cpo  # NOQA
    proxy = autopilot.get_proxy_object(processes.get_process_id(APP))
    return proxy.main_view
