# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu System Tests
# Copyright (C) 2016 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import time

try:
    from gi.repository import Gio
except SyntaxError:
    pass

from ubuntu_system_tests.helpers.init_systems import get_init_system
from ubuntu_system_tests.helpers.processes import (
    is_testability_enabled_for_process
)

from ubuntu_system_tests.helpers.ubuntu_keyboard.job import MaliitServerJob


maliit = MaliitServerJob()

init_system = get_init_system()


def restart_maliit_with_testability():
    """Restart maliit-server with testability enabled."""
    init_system.get_pid(maliit)
    pid = init_system.get_pid(maliit)
    if is_testability_enabled_for_process(pid):
        return
    init_system.stop(maliit)
    init_system.start(maliit, 'QT_LOAD_TESTABILITY=1')
    # This is needed to work around https://launchpad.net/bugs/1248913
    time.sleep(5)


def configure_osk_settings():
    """Configure OSK ready for testing by turning off all helpers."""
    gsettings = Gio.Settings.new("com.canonical.keyboard.maliit")
    gsettings.set_string("active-language", "en")
    gsettings.set_boolean("auto-capitalization", False)
    gsettings.set_boolean("auto-completion", False)
    gsettings.set_boolean("predictive-text", False)
    gsettings.set_boolean("spell-checking", False)
    gsettings.set_boolean("double-space-full-stop", False)
