# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu System Tests
# Copyright (C) 2014, 2015 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import logging
import fixtures

from ubuntu_system_tests.helpers.gsettings import set_key
from ubuntu_system_tests.helpers.init_systems import get_init_system
from ubuntu_system_tests.helpers.unity8.utils import (
    setup_unity,
    is_settings_wizard_enabled,
    set_settings_wizard,
    is_edge_intro_enabled, set_edge_intro)
from ubuntu_system_tests.helpers.unity8.job import Unity8Job

logger = logging.getLogger(__name__)

UBUNTU_PLATFORM_API_TEST_OVERRIDE = 'UBUNTU_PLATFORM_API_TEST_OVERRIDE'


class SettingsWizard(fixtures.Fixture):

    def __init__(self, enable):
        super().__init__()
        self.enable = enable

    def setUp(self):
        super().setUp()
        original_state = is_settings_wizard_enabled()
        if set_settings_wizard(self.enable):
            self.addCleanup(set_settings_wizard, original_state)


class SetupUnity8(fixtures.Fixture):
    def __init__(self, restart=False):
        self.restart = restart

    def setUp(self):
        super().setUp()
        setup_unity(self.restart)


class EnableUnity8FakeSensors(fixtures.Fixture):
    """Fixture to enable fake sensors for unity8."""
    def __init__(self):
        self.unity8 = Unity8Job()
        self.init_system = get_init_system()

    def setUp(self):
        super().setUp()
        self.init_system.ensure_stopped(self.unity8)
        # Restart unity at the end to unload fake sensors.
        # Unity process hangs on stop when fake sensors are loaded,
        # to workaround that we use the SetupUnity8 fixture as cleanup
        # which ensures we don't end up in a strayed state.
        self.addCleanup(setup_unity, restart=True)
        self.init_system.set_environment_variable(
            UBUNTU_PLATFORM_API_TEST_OVERRIDE, 'sensors',
            global_scope=False)
        self.addCleanup(self.init_system.unset_environment_variable,
                        UBUNTU_PLATFORM_API_TEST_OVERRIDE)
        args = ['QT_LOAD_TESTABILITY=1', '--no-wait']
        self.init_system.start(self.unity8, *args)
        self.unity8.sensors.validate_fifo_ready(self.unity8.name)
        self.unity8.sensors.setup_sensors(self.unity8.name)
        setup_unity()


class ChangeUsageMode(fixtures.Fixture):
    """Fixture to change Unity8 Usage Mode"""

    def __init__(self, value):
        self.schema = 'com.canonical.Unity8'
        self.key = 'usage-mode'
        self.value = value.capitalize()

    def setUp(self):
        super().setUp()
        set_key(self.schema, self.key, self.value)


class Tutorial(fixtures.Fixture):

    def __init__(self, enable):
        super().__init__()
        self.enable = enable

    def setUp(self):
        super().setUp()
        original_state = is_edge_intro_enabled()
        if set_edge_intro(self.enable):
            self.addCleanup(set_edge_intro, enable=original_state)
