# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu System Tests
# Copyright (C) 2014-2017 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import os
import subprocess


def merge_subunit_results(results_dir):
    """Merge results from subunit files located in sub-directories under the
    root results directory. Resulting subunit file will be placed at root of
    the results directory, over-writing any previous version.
    """
    subunit_results = 'test-results.subunit'
    root_subunit = os.path.join(results_dir, subunit_results)
    # get list of sub-dirs ordered by creation time to preserve execution order
    entries = [e for e in os.scandir(results_dir) if e.is_dir()]
    sub_dirs = [e.path for e in sorted(
        entries, reverse=True, key=lambda e: e.stat().st_ctime)]
    # remove any previous merged results before creating new version
    if os.path.isfile(root_subunit):
        os.remove(root_subunit)
    for sub_dir in sub_dirs:
        subunit = os.path.join(sub_dir, 'artifacts', subunit_results)
        append_subunit_results(root_subunit, subunit)


def append_subunit_results(destination_file_path, results_file_path):
    """Append the subunit results into another subunit file."""
    with open(destination_file_path, 'ab') as destination_file:
        with open(results_file_path, 'rb') as results_file:
            destination_file.write(results_file.read())


def convert_subunit_results_to_pyunit(results_dir):
    subunit_source_file_path = os.path.join(
        results_dir, 'test-results.subunit')
    pyunit_destination_file_path = os.path.join(
        results_dir, 'test-results.pyunit')

    with open(pyunit_destination_file_path, 'w') as pyunit_file:
        # subunit2pyunit prints its output to stderr, so that's what we have
        # to redirect to the file.
        subprocess.call(
            ['subunit2pyunit', subunit_source_file_path],
            universal_newlines=True,
            stderr=pyunit_file)


def print_results(artifacts_directory):
    """Print the results saved to the pyunit artifact."""
    pyunit_file_path = os.path.join(artifacts_directory, 'test-results.pyunit')
    with open(pyunit_file_path, 'r') as pyunit_file:
        print(pyunit_file.read())


def get_output_directory(config_stack):
    """Return path of the output directory to use. This will be a numbered
    sub-directory of output_dir specified in config.
    """
    output_dir = config_stack.get('output_dir')
    count = len([d for d in os.scandir(output_dir) if d.is_dir()])
    output_dir = os.path.join(output_dir, '{n:03d}'.format(n=count+1))
    os.makedirs(output_dir)
    return output_dir
