# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu System Tests
# Copyright (C) 2016 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import testscenarios

from ubuntu_system_tests.host import ppa
from ubuntu_system_tests.selftests.utils import ConfigBaseTestCase


class TestPPAArgsTestCase(ConfigBaseTestCase,
                          testscenarios.TestWithScenarios):

    scenarios = [
        ('single ppa', {
            'ppa_args': 'ppa:ci-train-ppa-service/landing-001',
            'expected_ppas': ['ppa:ci-train-ppa-service/landing-001']
        }),
        ('single silo', {
            'ppa_args': 'silo:landing-001',
            'expected_ppas': ['ppa:ci-train-ppa-service/landing-001']
        }),
        ('no ppa prefix', {
            'ppa_args': 'ci-train-ppa-service/landing-010',
            'expected_ppas': ['ppa:ci-train-ppa-service/landing-010']
        }),
        ('combined ppa silo and no prefix', {
            'ppa_args': (
                'ppa:ci-train-ppa-service/landing-001,'
                'silo:002,'
                'ci-train-ppa-service/003'),
            'expected_ppas': [
                'ppa:ci-train-ppa-service/landing-001',
                'ppa:ci-train-ppa-service/002',
                'ppa:ci-train-ppa-service/003'
            ]
        }),
        ('silo number format 100', {
            'ppa_args': 'silo:100',
            'expected_ppas': ['ppa:ci-train-ppa-service/100']
        }),
        ('ppa none', {
            'ppa_args': None,
            'expected_ppas': []
        }),
        ('ppa zero str', {
            'ppa_args': '',
            'expected_ppas': []
        }),
    ]

    def test_get_ppa_ids_for_args(self):
        fmt_ppas = ppa.get_ppa_ids(self.ppa_args)
        self.assertEqual(fmt_ppas, self.expected_ppas)
